API documentation
=================

.. autoclass:: picea.Tree
    :members:
    :undoc-members:

.. autoclass:: picea.tree.TreeIndex
    :members:
    :undoc-members:

.. autoclass:: picea.SequenceCollection
    :members:
    :undoc-members: